pyHMSA-gui
==========

.. image:: https://badge.fury.io/py/pyhmsa-gui.svg
   :target: http://badge.fury.io/py/pyhmsa-gui

.. image:: https://travis-ci.org/pyhmsa/pyhmsa-gui.svg?branch=master
   :target: https://travis-ci.org/pyhmsa/pyhmsa-gui
   
Provides graphical components to construct graphical interface based on the 
Python implementation of the 
`HMSA <http://www.csiro.au/luminescence/HMSA/index.html>`_ file format, 
`pyHMSA <https://pypi.python.org/pypi/pyHMSA>`_.
 
The components are designed in Qt using the library 
`PySide <http://qt-project.org/wiki/PySide>`_ and requires 
`matplotlib <http://matplotlib.org>`_ to run.

The library is provided under the MIT license.

More information can be found at the website:

http://pyhmsa.readthedocs.org

The most current development version is always available from our
GitHub repository:

https://github.com/pyhmsa/pyhmsa-gui

pyHMSA-gui was developed as part of the doctorate thesis project of 
Philippe T. Pinard at RWTH Aachen University (Aachen, Germany) under the 
supervision of Dr. Silvia Richter.